@@ -14,11 +14,7 @@ my $load = eval {
     1;
 };
 unless($load){ return 1 } else {
-    #require POSIX::Termios;
-    #POSIX::Termios->import;
     no strict;
-    #require POSIX;
-    #POSIX->import(':termios_h');
     my ($term, $oterm, $echo, $noecho, $fd_stdin);
 
     $fd_stdin = fileno(STDIN);
@@ -30,7 +26,7 @@ unless($load){ return 1 } else {
     $noecho   = $oterm & ~$echo;
 
     sub cbreak {
-        $term->setlflag($noecho);  # ok, so i don't want echo either
+        $term->setlflag($noecho);
         $term->setcc(VTIME, 1);
         $term->setattr($fd_stdin, TCSANOW);
     }
