@@ -15,8 +15,8 @@ use Carp;
 use HTTP::Tiny;
 
 sub tpb {
-    my @keywords = @_;
-    my $url = 'https://thepiratebay.org/search/' . join('%20', @keywords) . '/0/99/0';
+    my $keywords = shift;
+    my $url = 'https://thepiratebay.org/search/' . join('%20', @$keywords) . '/0/99/0';
 
     my $response = HTTP::Tiny->new->get( $url );
     croak "Failed to get $url\n" unless $response->{success};
